"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = __importDefault(require("http"));
const koa_1 = __importDefault(require("koa"));
const chokidar_1 = __importDefault(require("chokidar"));
const resolver_1 = require("./resolver");
const serverPluginModules_1 = require("./serverPluginModules");
const serverPluginVue_1 = require("./serverPluginVue");
const serverPluginHmr_1 = require("./serverPluginHmr");
const serverPluginServe_1 = require("./serverPluginServe");
const internalPlugins = [
    serverPluginModules_1.modulesPlugin,
    serverPluginVue_1.vuePlugin,
    serverPluginHmr_1.hmrPlugin,
    serverPluginServe_1.servePlugin
];
function createServer(config = {}) {
    const { root = process.cwd(), plugins = [], resolvers = [] } = config;
    const app = new koa_1.default();
    const server = http_1.default.createServer(app.callback());
    const watcher = chokidar_1.default.watch(root, {
        ignored: [/node_modules/]
    });
    const resolver = resolver_1.createResolver(root, resolvers);
    [...plugins, ...internalPlugins].forEach((m) => m({
        root,
        app,
        server,
        watcher,
        resolver
    }));
    return server;
}
exports.createServer = createServer;
